#include<cstdio>
#include<cstdlib>
#include<vector>
#include<sstream>
#include<iostream>
#include "../ojcontrol_ext.h"
using namespace std;

typedef pair<int, int> PII;

void writeline(const vector<PII >& V) {
  stringstream ss;
  ss << V.size();
  for(int i = 0; i < V.size(); i++)
      ss << " " << V[i].first << " " << V[i].second;
  writeline(ss.str());
}

struct point 
{
    int x,y;
    void input(FILE *fin)
    {
        fscanf(fin,"%d%d",&x,&y);
    }
    bool operator==(point a)const
    {
        return a.x == x && a.y == y;
    }
} p[30], q[30];

int gcd(int a, int b)
{
    if(a == 0 && b == 0) return 1;
    if(a == 0) return b;
    if(b == 0) return a;
    return gcd(b, a % b);
}

PII intersectX(int x, point &A, point &B)
{
  PII X = PII(A.y * (B.x - A.x) + (B.y - A.y) * (x - A.x), (B.x - A.x));
  int g = gcd(X.first, X.second);
  X.first /= g;
  X.second /= g;
  return X;
}

PII intersectY(int y, point &A, point &B)
{
  PII X = PII(A.x * (B.y - A.y) + (B.x - A.x) * (y - A.y),  (B.y - A.y));
  int g = gcd(X.first, X.second);
  X.first /= g;
  X.second /= g;
  return X;
}

int main(int argc, char* argv[]) {
  string filename = "convex.in";
  init_server(argc, argv, filename);

  FILE* fin = fopen(filename.c_str(), "r");
  int correct = 1;
  double x0, y0;

  int T, n, a;
  fscanf(fin, "%d", &T);
  writeline(T);
  while(T--) {
    fscanf(fin, "%d", &n);
    for(int i = 0; i < n; i++) p[i].input(fin);
    bool ok = false;
    string s, cmd;
    int ax = 0, ay = 0;
    for(int i = 0; i <= 500; i++) {
      if(!readline(s)) BC();
      stringstream ss(s);
      if(!(ss >> cmd)) PV("empty command");
      if(cmd == "AskX") {
        if(i == 500) PLE("Too many tests");
        ax++;
        if(!(ss >> x0)) PV("bad format");
        // if you want to put some bound on input x0..
        vector<PII > V;
        for(int i = 0; i < n; i++)
          if(x0 == p[i].x)
            V.push_back(PII(p[i].y, 1));
        for(int i = 0; i < n; i++)
        {
          int j = (i + 1) % n;
          if((p[i].x < x0 && x0 < p[j].x) || (p[j].x < x0 && x0 < p[i].x))
          V.push_back(intersectX(x0, p[i], p[j]));
        }
        writeline(V);
      }
      else if(cmd == "AskY") {
        if(i == 500) PLE("Too many tests");
        ay++;
        if(!(ss >> y0)) PV("bad format");
        // if you want to put some bound on input x0..
        vector<PII > V;
        for(int i = 0; i < n; i++)
          if(y0 == p[i].y)
            V.push_back(PII(p[i].x,1));
        for(int i = 0; i < n; i++)
        {
          int j = (i + 1) % n;
          if((p[i].y < y0 && y0 < p[j].y) || (p[j].y < y0 && y0 < p[i].y))
            V.push_back(intersectY(y0, p[i], p[j]));
        }
        writeline(V);
      }
      else if(cmd == "Answer") {
        int nn;
        if(!(ss >> nn)) PV("bad format");
        if(n != nn) WA("incorrect number of vertices");
        int flag = 0;
        for(int i = 0; i < n; i++) 
        {
            if(!readline(s)) { flag = 1; break; }
            stringstream ss(s);
            ss >> q[i].x >> q[i].y;
        }
        if(flag) WA("incomplete polygon");
        int i;
        for(i = 0; i < n; i++)
          if(q[i] == p[0])
            break;
        ok = true;
        for(int j = 0; j < n; j++)
          if(!(p[j] == q[(i + j) % n]))
            ok = false;
        if(ok) cerr << "Solved with " << ax << " AskX and " << ay << " AskY\n";
        else WA("Incorrect polygon");
        break;
      }
      else PV("no such command"); // invalid command
    }
    if(!ok) {
      correct = 0;
      break; // no need to give more tests
    } 
  }
  fclose(fin);

  if(correct) cerr << "Correct\n";

  return 0;
}
